@@ -7,17 +7,20 @@
 # http://search.cpan.org/dist/Devel-NYTProf/
 #
 ###########################################################
-# $Id: Core.pm 1427 2012-08-11 10:53:27Z tim.bunce@gmail.com $
+# $Id: Core.pm 1441 2012-12-26 18:42:41Z tim.bunce@gmail.com $
 ###########################################################
 package Devel::NYTProf::Core;
 
 
 use XSLoader;
 
-our $VERSION = '4.09';    # increment with XS changes too
+our $VERSION = '4.11';    # increment with XS changes too
 
 XSLoader::load('Devel::NYTProf', $VERSION);
 
+# Fudging for https://rt.cpan.org/Ticket/Display.html?id=82256
+$Devel::NYTProf::StrEvalTestPad = ($] <= 5.017003) ? ";\n" : "";
+
 if (my $NYTPROF = $ENV{NYTPROF}) {
     for my $optval ( $NYTPROF =~ /((?:[^\\:]+|\\.)+)/g) {
         my ($opt, $val) = $optval =~ /^((?:[^\\=]+|\\.)+)=((?:[^\\=]+|\\.)+)\z/;
